# -*- coding: utf-8 -*-
from django.utils.translation import gettext_lazy as _
from rest_framework import viewsets
from rest_framework.decorators import action
from rest_framework.response import Response
from thx.api.mixins import ThuxModelMixin
from thx.role.core.views import ThuxRoleViewSetMixin

from ... import models
from . import serializers, filters, permissions

STATUS_CODES = ((0, _('disable')), (1, _('enable')),)


# CURRENCY
class CurrencyViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    """
    CurrencyViewSet
    -----------

    :action list: Return the currency list.
        `Profiles`: `superuser`, `staff`

    :action retrieve: Return the given currency.
        `Profiles`: `superuser`, `staff`

    :action light: Return the currency list using light serialization.
        `Profiles`: `superuser`, `staff`

    :action create: Create a new currency instance.
        `Profiles`: `superuser`, `staff`

    :action update: Update a currency instance.
        `Profiles`: `superuser`, `staff`

    :action partial_update: Patch a currency instance.
        `Profiles`: `superuser`, `staff`

    :action destroy: Delete a currency instance.
        `Profiles`: `superuser`, `staff`
    """
    queryset = models.Currency.objects.all()
    serializer_class = serializers.CurrencySerializer
    filter_backends = (filters.CurrencyFilterBackend,)
    permission_classes = (permissions.CurrencyPermission,)

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        """
        Enable a currency instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        """
        Disable a currency instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path="status-choices")
    def status_choices(self, request, *args, **kwargs):
        """
        Return the status choices options.
        `Profiles`: `superuser`, `staff`
        """
        return Response(STATUS_CODES)
